@@ -668,6 +668,9 @@ class BaseAutoML(BaseEstimator, ABC):
             k_folds = 5
             if folds_cnt >= 15:
                 k_folds = 10
+            # too small dataset to run 10-fold CV
+            if k_folds == 10 and self.n_rows_in_ <= 1000:
+                k_folds = 5
             self._validation_strategy["validation_type"] = "kfold"
             del self._validation_strategy["train_ratio"]
             self._validation_strategy["k_folds"] = k_folds
@@ -682,8 +685,10 @@ class BaseAutoML(BaseEstimator, ABC):
                 cv += ["Shuffle"]
             if self._validation_strategy.get("stratify", False):
                 cv += ["Stratify"]
-            self.select_and_save_best() # save validation strategy
-            os.remove(os.path.join(self._results_path, "best_model.txt")) # remove the file
+            self.select_and_save_best()  # save validation strategy
+            os.remove(
+                os.path.join(self._results_path, "best_model.txt")
+            )  # remove the file
             self.verbose_print(f"Validation strategy: {k_folds}-fold CV {','.join(cv)}")
         else:
             # cant stack models for train/test split
@@ -896,7 +901,8 @@ class BaseAutoML(BaseEstimator, ABC):
         # Select best model based on the lowest loss
         if self._models:
             self._best_model = min(
-                [m for m in self._models if m.is_valid()], key=lambda x: x.get_final_loss()
+                [m for m in self._models if m.is_valid()],
+                key=lambda x: x.get_final_loss(),
             )
             with open(os.path.join(self._results_path, "best_model.txt"), "w") as fout:
                 fout.write(f"{self._best_model.get_name()}")
@@ -936,7 +942,9 @@ class BaseAutoML(BaseEstimator, ABC):
             # save report
             ldb["Link"] = [f"[Results link]({m}/README.md)" for m in ldb["name"].values]
             ldb.insert(loc=0, column="Best model", value="")
-            ldb.loc[ldb.name == self._best_model.get_name(), "Best model"] = "**the best**"
+            ldb.loc[
+                ldb.name == self._best_model.get_name(), "Best model"
+            ] = "**the best**"
 
             with open(os.path.join(self._results_path, "README.md"), "w") as fout:
                 fout.write(f"# AutoML Leaderboard\n\n")
